@@ -1,6 +1,6 @@
 package Padre::Plugin::SpellCheck;
 
-use v5.10;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ use Padre::Unload ();
 use File::Which   ();
 use Try::Tiny;
 
-our $VERSION = '1.31';
+our $VERSION = '1.33';
 use parent qw( Padre::Plugin );
 
 # Child modules we need to unload when disabled
@@ -264,7 +264,7 @@ sub event_on_context_menu {
 
 	$menu->AppendSeparator;
 
-	my $item = $menu->Append( -1, Wx::gettext('SpellCheck Preferences') );
+	my $item = $menu->Append( -1, Wx::gettext('SpellCheck Preferences...') );
 	Wx::Event::EVT_MENU(
 		$self->main,
 		$item,
@@ -290,6 +290,9 @@ sub menu_plugins_simple {
 	];
 }
 
+=pod
+
+=encoding utf8
 
 =head1 NAME
 
@@ -297,16 +300,17 @@ Padre::Plugin::SpellCheck - Check spelling in Padre, The Perl IDE.
 
 =head1 VERSION
 
-version 1.31
+version: 1.33
 
 =head1 DESCRIPTION
 
-For Padre 0.97+
+For Padre 0.98
 
 This plug-in allows one to check there spelling within Padre using
-C<F7> (standard spelling short-cut across text processors). 
+C<F7> (standard spelling short-cut across text processors).
 
-One can change the dictionary language used (based upon install languages) in the preferences window via Plug-in Manager. 
+One can change the dictionary language used (based upon install languages) in
+ the preferences window via Plug-in Manager.
 Note that preferences can B<only> be setup while the plugin is B<disabled>.
 Preferences are persistent. You need to Save your preferred language.
 
@@ -349,7 +353,7 @@ Return the plug-in's configuration, or a suitable default one if none exist prev
 
 =item plugin_preferences()
 
-Spelling preferences window normaly access via Plug-in Manager
+Spelling preferences window normally access via Plug-in Manager
 
 =item plugin_icon()
 
@@ -375,9 +379,9 @@ Spell checks the current selection (or the whole document).
 
 =head1 BUGS and LIMITATIONS
 
-If you upgrade your os, and run Perl from a local/lib, 
-you may find Hunspell stops showing local dictionary s in preferences, 
-you will need to un-install Text::Hunspell and re-install in cpan.
+If you upgrade your OS, and run Perl from a local/lib,
+ you may find Hunspell stops showing local dictionary in preferences,
+ you will need to un-install Text::Hunspell and re-install in CPAN.
 
 
 Spell-checking non-ascii files has bugs: the selection does not
@@ -388,8 +392,9 @@ unfortunately, there's nothing that I can do in this plug-in to
 tackle this bug.
 
 Please report any bugs or feature requests to C<padre-plugin-spellcheck
-at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Padre-Plugin-
-SpellCheck>. I will be notified, and then you'll automatically be
+at rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Padre-Plugin-SpellCheck>.
+I will be notified, and then you'll automatically be
 notified of progress on your bug as I make changes.
 
 
@@ -406,11 +411,10 @@ L<http://www.famfamfam.com/lab/icons/silk/>.
 
 L<http://padre.perlide.org/trac/wiki/PadrePluginSpellCheck>
 
-=item * Our svn repository 
+=item * Our svn repository
 
-L<http://svn.perlide.org/padre/trunk/Padre-Plugin-SpellCheck>, 
-and can be browsed at 
-L<http://padre.perlide.org/browser/trunk/Padre-Plugin-SpellCheck>.
+L<http://svn.perlide.org/padre/trunk/Padre-Plugin-SpellCheck>,
+and can be browsed at L<http://padre.perlide.org/browser/trunk/Padre-Plugin-SpellCheck>.
 
 =back
 
@@ -436,7 +440,7 @@ Everything Aspell related: L<http://aspell.net>.
 
 Everything Hunspell related: L<http://hunspell.sourceforge.net/>.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
 Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
 
@@ -447,18 +451,21 @@ Fayland Lam E<lt>fayland at gmail.comE<gt>
 Jerome Quelin E<lt>jquelin@gmail.comE<gt>
 
 
+=head2 CONTRIBUTORS
+
+none at present
+
 =head1 COPYRIGHT
 
-This software is copyright (c) 2010 by Fayland Lam, Jerome Quelin.
+Copyright E<copy> 2010 by Fayland Lam, Jerome Quelin.
+
+Also Copyright E<copy> 2009-2013 the Padre::Plugin::Git  L</AUTHOR> and L</CONTRIBUTORS>
+as listed above.
 
 =head1 LICENSE
 
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
+This program is free software; you can redistribute it and/or modify
+ it under the same terms as Perl 5 itself.
 
 =cut
 
-# Copyright 2008-2012 The Padre development team as listed in Padre.pm.
-# LICENSE
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl 5 itself.
