@@ -4,17 +4,17 @@ use v5.10;
 use warnings;
 use strict;
 
-our $VERSION = '1.31';
+our $VERSION = '1.33';
 
 use Padre::Logger;
 use Padre::Unload ();
 
 use Class::Accessor 'antlers';
 has _ignore  => ( is => 'rw', isa => 'Str' ); # list of words to ignore
-has _speller => ( is => 'rw', isa => 'Str' ); # real text::aspell object
+has _speller => ( is => 'rw', isa => 'Str' ); # real text::Aspell object
 
 # FIXME: as soon as wxWidgets/wxPerl supports
-# newer version of STC:
+# newer version 1.31_03
 # number of UTF8 characters
 # used in calculating current possition
 has _utf_chars => ( is => 'rw', isa => 'Str' );
@@ -59,7 +59,7 @@ sub _init {
 		if ( exists $MIMETYPE_MODE{$mimetype} ) {
 			if ( not defined $speller->set_option( 'mode', $MIMETYPE_MODE{$mimetype} ) ) {
 				my $err = $speller->errstr;
-				warn "Could not set aspell mode '$MIMETYPE_MODE{$mimetype}': $err\n";
+				warn "Could not set Aspell mode '$MIMETYPE_MODE{$mimetype}': $err\n";
 			}
 		}
 
@@ -167,7 +167,7 @@ Padre::Plugin::SpellCheck::Engine - Check spelling in Padre, The Perl IDE.
 
 =head1 VERSION
 
-version 1.31
+version: 1.33
 
 =head1 PUBLIC METHODS
 
@@ -198,10 +198,10 @@ Tell engine to ignore C<$word> for rest of the spell check.
 
 =item * my @dictionaries = $engine->dictionaries;
 
-Return a (reduced) list of dictionaries installed with aspell. The
-names returned are the dictionary locale names (eg C<en_US>). Note
+Return a (reduced) list of dictionaries installed with Aspell. The
+names returned are the dictionary locale names (e.g. C<en_US>). Note
 that only plain locales are reported, the variations coming with
-aspell are stripped.
+Aspell are stripped.
 
 =item * my @suggestions = $engine->get_suggestions( $word );
 
@@ -223,28 +223,22 @@ Padre, Class::XSAccessor and either or ( Text::Hunspell or Text::Aspell )
 For all related information (bug reporting, source code repository,
 etc.), refer to L<Padre::Plugin::SpellCheck>.
 
-=head1 AUTHORS
 
-Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
+=head1 AUTHOR
 
-Ahmad M. Zawawi E<lt>ahmad.zawawi@gmail.comE<gt>
+See L<Padre::Plugin::SpellCheck>
 
-Fayland Lam E<lt>fayland@gmail.comE<gt>
+=head2 CONTRIBUTORS
 
-Jerome Quelin E<lt>jquelin@gmail.comE<gt>
+See L<Padre::Plugin::SpellCheck>
 
+=head1 COPYRIGHT
 
-=head1 COPYRIGHT AND LICENSE
+See L<Padre::Plugin::SpellCheck>
 
-This software is copyright (c) 2010 by Fayland Lam, Jerome Quelin.
+=head1 LICENSE
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+See L<Padre::Plugin::SpellCheck>
 
 =cut
 
-
-# Copyright 2008-2012 The Padre development team as listed in Padre.pm.
-# LICENSE
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl 5 itself.
